@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Qu-Prolog 9.7 and later versions
-%  Last updated on April 13, 2020
+%  Last updated on May 22, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -104,7 +104,7 @@ findall(Term, Goal, List, Tail) :-
 
 % format(+stream_or_alias, +character_code_list_or_atom, +list)
 
-format(Stream, Format, Arguments) :-
+'$lgt_format'(Stream, Format, Arguments) :-
 	atom_chars(Format, Chars),
 	format_(Chars, Stream, Arguments).
 
@@ -150,7 +150,7 @@ format_spec_('~', Stream, Arguments, Arguments) :-
 
 % format(+character_code_list_or_atom, +list)
 
-format(Format, Arguments) :-
+'$lgt_format'(Format, Arguments) :-
 	current_output(Stream),
 	format(Stream, Format, Arguments).
 
