@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Scryer Prolog
-%  Last updated on April 13, 2020
+%  Last updated on May 20, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -68,6 +68,12 @@
 
 :- use_module(library(format), [format/3, format/2]).
 
+'$lgt_format'(Stream, Format, Arguments) :-
+	format(Stream, Format, Arguments).
+
+'$lgt_format'(Format, Arguments) :-
+	format(Format, Arguments).
+
 
 % numbervars(?term, +integer, ?integer)
 
@@ -207,12 +213,12 @@
 '$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(Major, Minor, Path))).
 '$lgt_prolog_feature'(prolog_conformance, lax).	% either lax or strict
 
-'$lgt_prolog_feature'(encoding_directive, unsupported).
+'$lgt_prolog_feature'(encoding_directive, source).
 '$lgt_prolog_feature'(tabling, unsupported).
 '$lgt_prolog_feature'(threads, unsupported).
 '$lgt_prolog_feature'(modules, supported).
 '$lgt_prolog_feature'(coinduction, unsupported).
-'$lgt_prolog_feature'(unicode, unsupported).
+'$lgt_prolog_feature'(unicode, bmp).
 
 
 
@@ -347,14 +353,12 @@
 
 '$lgt_directory_hash_as_atom'(_, '').
 
-
 % '$lgt_compile_prolog_code'(+atom, +atom, +list)
 %
 % compile to disk a Prolog file, resulting from a
 % Logtalk source file, given a list of flags
 
-'$lgt_compile_prolog_code'(File, Source, Options) :-
-	?????.
+'$lgt_compile_prolog_code'(_, _, _).
 
 
 % '$lgt_load_prolog_code'(+atom, +atom, +list)
@@ -362,8 +366,8 @@
 % compile and load a Prolog file, resulting from a
 % Logtalk source file, given a list of flags
 
-'$lgt_load_prolog_code'(File, Source, Options) :-
-	?????
+'$lgt_load_prolog_code'(File, _Source, _Options) :-
+	consult(File).
 
 
 % '$lgt_file_modification_time'(+atom, -nonvar)
@@ -403,8 +407,7 @@
 
 % '$lgt_stream_current_line_number'(@stream, -integer)
 
-'$lgt_stream_current_line_number'(Stream, Line) :-
-	?????
+'$lgt_stream_current_line_number'(_, -1).
 
 
 
@@ -419,13 +422,13 @@
 % '$lgt_open'(+atom, +atom, -stream, @list)
 
 '$lgt_open'(File, Mode, Stream, Options) :-
-	?????
+	open(File, Mode, Stream, Options).
 
 
 % '$lgt_close'(@stream)
 
 '$lgt_close'(Stream) :-
-	?????
+	close(Stream).
 
 
 
@@ -440,8 +443,8 @@
 
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
-'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	?????
+'$lgt_read_term'(Stream, Term, Options, '-'(-1, -1), Variables) :-
+	read_term(Stream, Term, [variable_names(Variables)| Options]).
 
 
 
@@ -476,8 +479,7 @@
 
 % '$lgt_logtalk_prolog_encoding'(?atom, ?atom)
 
-'$lgt_logtalk_prolog_encoding'(_, _, _) :-
-	fail.
+'$lgt_logtalk_prolog_encoding'('UTF-8', _).
 
 
 
@@ -574,15 +576,15 @@ term_hash(_, _, _, _) :-
 
 % '$lgt_string'(@term)
 
-'$lgt_string'(Term) :-
-	string(Term).
+'$lgt_string'(_) :-
+	fail.
 
 
 % '$lgt_string_codes'(+string, -list(codes))
 % '$lgt_string_codes'(-string, +list(codes))
 
-'$lgt_string_codes'(String, Codes) :-
-	?????
+'$lgt_string_codes'(_, _) :-
+	fail.
 
 
 
