@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for tuProlog 2.9.0 and later versions
-%  Last updated on April 13, 2020
+%  Last updated on May 22, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -69,7 +69,7 @@ forall(Generate, Test) :-
 
 % format(+stream_or_alias, +character_code_list_or_atom, +list)
 
-format(Stream, Format, Arguments) :-
+'$lgt_format'(Stream, Format, Arguments) :-
 	atom_chars(Format, Chars),
 	format_(Chars, Stream, Arguments).
 
@@ -117,7 +117,7 @@ format_spec_('~', Stream, Arguments, Arguments) :-
 
 % format(+character_code_list_or_atom, +list)
 
-format(Format, Arguments) :-
+'$lgt_format'(Format, Arguments) :-
 	current_output(Stream),
 	format(Stream, Format, Arguments).
 
@@ -462,53 +462,6 @@ numbervars(Term, From, Next) :-
 
 
 
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  time and date predicates
-%
-%  if your Prolog compiler does not provide access to the operating system
-%  time and date just write dummy definitions
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_current_date'(?integer, ?integer, ?integer)
-
-'$lgt_current_date'(Year, Month, Day) :-
-	class('java.util.Calendar') <- getInstance returns Instance,
-	Instance.'YEAR' <- get(YEAR), Instance <- get(YEAR) returns Year,
-	Instance.'MONTH' <- get(MONTH), Instance <- get(MONTH) returns Month0, Month is Month0 + 1,
-	Instance.'DAY_OF_MONTH' <- get(DAY), Instance <- get(DAY) returns Day.
-
-
-% '$lgt_current_time'(?integer, ?integer, ?integer)
-
-'$lgt_current_time'(Hours, Minutes, Seconds) :-
-	class('java.util.Calendar') <- getInstance returns Instance,
-	Instance.'HOUR' <- get(HOUR), Instance <- get(HOUR) returns Hours,
-	Instance.'MINUTE' <- get(MINUTE), Instance <- get(MINUTE) returns Minutes,
-	Instance.'SECOND' <- get(SECOND), Instance <- get(SECOND) returns Seconds.
-
-
-
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  timing predicate
-%
-%  if your Prolog compiler does not provide access to a timing predicate
-%  just write a dummy definition
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_cpu_time'(-Seconds)
-
-'$lgt_cpu_time'(Seconds) :-
-	class('java.lang.System') <- currentTimeMillis returns Miliseconds,
-	Seconds is Miliseconds / 1000 .
-
-
-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  getting stream current line number
