@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for XSB 3.8.0 or later versions
-%  Last updated on April 13, 2020
+%  Last updated on May 22, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -64,13 +64,15 @@
 
 
 % format(+stream_or_alias, +character_code_list_or_atom, +list)
-
-:- import format/3 from format.
-
-
 % format(+character_code_list_or_atom, +list)
 
-:- import format/2 from format.
+:- import format/3, format/2 from format.
+
+'$lgt_format'(Stream, Format, Arguments) :-
+	format(Stream, Format, Arguments).
+
+'$lgt_format'(Format, Arguments) :-
+	format(Format, Arguments).
 
 
 % numbervars(?term, +integer, ?integer) -- built-in
