@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk uninstall script
-##   Last updated on April 9, 2019
+##   Last updated on June 5, 2020
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -63,6 +63,7 @@ rm -rf "$directory"
 rm -f logtalk
 cd ../bin || exit 1
 rm -f bplgt
+rm -f ciaolgt
 rm -f cxlgt
 rm -f eclipselgt
 rm -f gplgt
@@ -79,11 +80,11 @@ rm -f logtalk_tester
 rm -f logtalk_doclet
 rm -f logtalk_user_setup
 rm -f logtalk_version_select
-rm -f lplgt
 rm -f qplgt
 rm -f quintuslgt
 rm -f sicstuslgt
 rm -f swilgt
+rm -f taulgt
 rm -f xsblgt
 rm -f xsbmtlgt
 rm -f yaplgt
@@ -105,11 +106,11 @@ rm -f logtalk_tester.1.gz
 rm -f logtalk_doclet.1.gz
 rm -f logtalk_user_setup.1.gz
 rm -f logtalk_version_select.1.gz
-rm -f lplgt.1.gz
 rm -f qplgt.1.gz
 rm -f quintuslgt.1.gz
 rm -f sicstuslgt.1.gz
 rm -f swilgt.1.gz
+rm -f taulgt.1.gz
 rm -f xsblgt.1.gz
 rm -f xsbmtlgt.1.gz
 rm -f yaplgt.1.gz
